@@ -62,7 +62,7 @@ public:
 	static type get_file_info(native_string const& path, bool &is_link, int64_t* size, datetime* modification_time, int* mode);
 
 	/// Gets size of file, returns -1 on error.
-	static int64_t get_size(native_string const& path, bool *is_link = 0);
+	static int64_t get_size(native_string const& path, bool *is_link = nullptr);
 
 	/// \brief Begins enumerating a directory.
 	///
@@ -88,22 +88,22 @@ public:
 
 private:
 #ifndef FZ_WINDOWS
-	void alloc_path_buffer(char const* file); // Ensures m_raw_path is large enough to hold path and filename
+	void alloc_path_buffer(char const* filename); // Ensures m_raw_path is large enough to hold path and filename
 #endif
 
 	// State for directory enumeration
-	bool m_dirs_only{};
+	bool dirs_only_{};
 
 #ifdef FZ_WINDOWS
 	WIN32_FIND_DATA m_find_data{};
 	HANDLE m_hFind{INVALID_HANDLE_VALUE};
-	bool m_found{};
+	bool has_next_{};
 	native_string m_find_path;
 #else
 	char* m_raw_path{};
 	char* m_file_part{}; // Points into m_raw_path past the trailing slash of the path part
 	int m_buffer_length{};
-	DIR* m_dir{};
+	DIR* dir_{};
 #endif
 };
 
