@@ -32,27 +32,29 @@ local_filesys::~local_filesys()
 
 local_filesys::type local_filesys::get_file_type(native_string const& path, bool follow_links)
 {
-	if (path.size() > 1 && path.back() == '/') {
+	if (path.size() > 1 && is_separator(path.back())) {
 		native_string tmp = path;
 		tmp.pop_back();
 		return get_file_type(tmp);
 	}
 
 #ifdef FZ_WINDOWS
-	DWORD result = GetFileAttributes(path.c_str());
-	if (result == INVALID_FILE_ATTRIBUTES) {
+	WIN32_FIND_DATA data;
+	HANDLE hFind = FindFirstFile(path.c_str(), &data);
+	if (hFind == INVALID_HANDLE_VALUE) {
 		return unknown;
 	}
+	FindClose(hFind);
 
-	bool is_dir = (result & FILE_ATTRIBUTE_DIRECTORY) != 0;
+	bool is_dir = (data.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY) != 0;
 
-	if (result & FILE_ATTRIBUTE_REPARSE_POINT) {
+	if (data.dwFileAttributes & FILE_ATTRIBUTE_REPARSE_POINT && IsReparseTagNameSurrogate(data.dwReserved0)) {
 		if (!follow_links) {
 			return link;
 		}
 
 		// Follow the reparse point
-		HANDLE hFile = is_dir ? INVALID_HANDLE_VALUE : CreateFile(path.c_str(), FILE_READ_ATTRIBUTES | FILE_READ_EA, FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE, 0, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, 0);
+		HANDLE hFile = is_dir ? INVALID_HANDLE_VALUE : CreateFile(path.c_str(), FILE_READ_ATTRIBUTES | FILE_READ_EA, FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE, nullptr, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, nullptr);
 		if (hFile == INVALID_HANDLE_VALUE) {
 			return unknown;
 		}
@@ -60,7 +62,7 @@ local_filesys::type local_filesys::get_file_type(native_string const& path, bool
 		BY_HANDLE_FILE_INFORMATION info{};
 		int ret = GetFileInformationByHandle(hFile, &info);
 		CloseHandle(hFile);
-		if (!ret || (info.dwFileAttributes & FILE_ATTRIBUTE_REPARSE_POINT)) {
+		if (!ret) {
 			return unknown;
 		}
 
@@ -98,18 +100,17 @@ local_filesys::type local_filesys::get_file_type(native_string const& path, bool
 
 local_filesys::type local_filesys::get_file_info(native_string const& path, bool &is_link, int64_t* size, datetime* modification_time, int *mode)
 {
-#ifdef FZ_WINDOWS
-	native_string fixed_path = path;
-
-	if (fixed_path.size() > 1 && is_separator(fixed_path.back())) {
-		fixed_path.pop_back();
+	if (path.size() > 1 && is_separator(path.back())) {
+		native_string tmp = path;
+		tmp.pop_back();
+		return get_file_info(tmp, is_link, size, modification_time, mode);
 	}
-
+#ifdef FZ_WINDOWS
 	is_link = false;
 
-	WIN32_FILE_ATTRIBUTE_DATA attributes;
-	BOOL result = GetFileAttributesEx(fixed_path.c_str(), GetFileExInfoStandard, &attributes);
-	if (!result) {
+	WIN32_FIND_DATA data;
+	HANDLE hFind = FindFirstFile(path.c_str(), &data);
+	if (hFind == INVALID_HANDLE_VALUE) {
 		if (size) {
 			*size = -1;
 		}
@@ -121,19 +122,19 @@ local_filesys::type local_filesys::get_file_info(native_string const& path, bool
 		}
 		return unknown;
 	}
+	FindClose(hFind);
 
-	bool is_dir = (attributes.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY) != 0;
+	bool is_dir = (data.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY) != 0;
 
-	if (attributes.dwFileAttributes & FILE_ATTRIBUTE_REPARSE_POINT) {
+	if (data.dwFileAttributes & FILE_ATTRIBUTE_REPARSE_POINT && IsReparseTagNameSurrogate(data.dwReserved0)) {
 		is_link = true;
 
-		HANDLE hFile = is_dir ? INVALID_HANDLE_VALUE : CreateFile(fixed_path.c_str(), FILE_READ_ATTRIBUTES | FILE_READ_EA, FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE, 0, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, 0);
+		HANDLE hFile = is_dir ? INVALID_HANDLE_VALUE : CreateFile(path.c_str(), FILE_READ_ATTRIBUTES | FILE_READ_EA, FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE, nullptr, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, nullptr);
 		if (hFile != INVALID_HANDLE_VALUE) {
 			BY_HANDLE_FILE_INFORMATION info{};
 			int ret = GetFileInformationByHandle(hFile, &info);
 			CloseHandle(hFile);
-			if (ret != 0 && !(info.dwFileAttributes & FILE_ATTRIBUTE_REPARSE_POINT)) {
-
+			if (ret != 0) {
 				if (modification_time) {
 					if (!modification_time->set(info.ftLastWriteTime, datetime::milliseconds)) {
 						modification_time->set(info.ftCreationTime, datetime::milliseconds);
@@ -172,14 +173,14 @@ local_filesys::type local_filesys::get_file_info(native_string const& path, bool
 	}
 
 	if (modification_time) {
-		*modification_time = datetime(attributes.ftLastWriteTime, datetime::milliseconds);
+		*modification_time = datetime(data.ftLastWriteTime, datetime::milliseconds);
 		if (modification_time->empty()) {
-			*modification_time = datetime(attributes.ftCreationTime, datetime::milliseconds);
+			*modification_time = datetime(data.ftCreationTime, datetime::milliseconds);
 		}
 	}
 
 	if (mode) {
-		*mode = (int)attributes.dwFileAttributes;
+		*mode = (int)data.dwFileAttributes;
 	}
 
 	if (is_dir) {
@@ -190,17 +191,11 @@ local_filesys::type local_filesys::get_file_info(native_string const& path, bool
 	}
 	else {
 		if (size) {
-			*size = make_int64fzT(attributes.nFileSizeHigh, attributes.nFileSizeLow);
+			*size = make_int64fzT(data.nFileSizeHigh, data.nFileSizeLow);
 		}
 		return file;
 	}
 #else
-	if (path.size() > 1 && path.back() == '/') {
-		native_string tmp = path;
-		tmp.pop_back();
-		return get_file_info(tmp, is_link, size, modification_time, mode);
-	}
-
 	struct stat buf;
 	static_assert(sizeof(buf.st_size) >= 8, "The st_size member of struct stat must be 8 bytes or larger.");
 
@@ -271,7 +266,7 @@ bool local_filesys::begin_find_files(native_string path, bool dirs_only)
 
 	end_find_files();
 
-	m_dirs_only = dirs_only;
+	dirs_only_ = dirs_only;
 #ifdef FZ_WINDOWS
 	if (is_separator(path.back())) {
 		m_find_path = path;
@@ -282,21 +277,23 @@ bool local_filesys::begin_find_files(native_string path, bool dirs_only)
 		path += fzT("\\*");
 	}
 
-	m_hFind = FindFirstFileEx(path.c_str(), FindExInfoStandard, &m_find_data, dirs_only ? FindExSearchLimitToDirectories : FindExSearchNameMatch, 0, 0);
+	m_hFind = FindFirstFileEx(path.c_str(), FindExInfoStandard, &m_find_data, dirs_only ? FindExSearchLimitToDirectories : FindExSearchNameMatch, nullptr, 0);
 	if (m_hFind == INVALID_HANDLE_VALUE) {
-		m_found = false;
+		has_next_ = false;
 		return false;
 	}
 
-	m_found = true;
+	has_next_ = true;
 	return true;
 #else
-	if (path.size() > 1 && path.back() == '/')
+	if (path.size() > 1 && path.back() == '/') {
 		path.pop_back();
+	}
 
-	m_dir = opendir(path.c_str());
-	if (!m_dir)
+	dir_ = opendir(path.c_str());
+	if (!dir_) {
 		return false;
+	}
 
 	m_raw_path = new char[path.size() + 2048 + 2];
 	m_buffer_length = path.size() + 2048 + 2;
@@ -305,8 +302,9 @@ bool local_filesys::begin_find_files(native_string path, bool dirs_only)
 		m_raw_path[path.size()] = '/';
 		m_file_part = m_raw_path + path.size() + 1;
 	}
-	else
+	else {
 		m_file_part = m_raw_path + path.size();
+	}
 
 	return true;
 #endif
@@ -315,73 +313,80 @@ bool local_filesys::begin_find_files(native_string path, bool dirs_only)
 void local_filesys::end_find_files()
 {
 #ifdef FZ_WINDOWS
-	m_found = false;
+	has_next_ = false;
 	if (m_hFind != INVALID_HANDLE_VALUE) {
 		FindClose(m_hFind);
 		m_hFind = INVALID_HANDLE_VALUE;
 	}
 #else
-	if (m_dir) {
-		closedir(m_dir);
-		m_dir = 0;
+	if (dir_) {
+		closedir(dir_);
+		dir_ = nullptr;
 	}
 	delete [] m_raw_path;
-	m_raw_path = 0;
-	m_file_part = 0;
+	m_raw_path = nullptr;
+	m_file_part = nullptr;
 #endif
 }
 
 bool local_filesys::get_next_file(native_string& name)
 {
 #ifdef FZ_WINDOWS
-	if (!m_found)
+	if (!has_next_) {
 		return false;
+	}
 	do {
 		name = m_find_data.cFileName;
 		if (name.empty()) {
-			m_found = FindNextFile(m_hFind, &m_find_data) != 0;
+			has_next_ = FindNextFile(m_hFind, &m_find_data) != 0;
 			return true;
 		}
-		if (name == fzT(".") || name == fzT(".."))
+		if (name == fzT(".") || name == fzT("..")) {
 			continue;
+		}
 
-		if (m_dirs_only && !(m_find_data.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY))
+		if (dirs_only_ && !(m_find_data.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY)) {
 			continue;
+		}
 
-		m_found = FindNextFile(m_hFind, &m_find_data) != 0;
+		has_next_ = FindNextFile(m_hFind, &m_find_data) != 0;
 		return true;
-	} while ((m_found = FindNextFile(m_hFind, &m_find_data) != 0));
+	} while ((has_next_ = FindNextFile(m_hFind, &m_find_data) != 0));
 
 	return false;
 #else
-	if (!m_dir)
+	if (!dir_) {
 		return false;
+	}
 
 	struct dirent* entry;
-	while ((entry = readdir(m_dir))) {
+	while ((entry = readdir(dir_))) {
 		if (!entry->d_name[0] ||
 			!strcmp(entry->d_name, ".") ||
 			!strcmp(entry->d_name, ".."))
 			continue;
 
-		if (m_dirs_only) {
+		if (dirs_only_) {
 #if HAVE_STRUCT_DIRENT_D_TYPE
 			if (entry->d_type == DT_LNK) {
 				bool wasLink;
 				alloc_path_buffer(entry->d_name);
 				strcpy(m_file_part, entry->d_name);
-				if (get_file_info(m_raw_path, wasLink, 0, 0, 0) != dir)
+				if (get_file_info(m_raw_path, wasLink, nullptr, nullptr, nullptr) != dir) {
 					continue;
+				}
 			}
-			else if (entry->d_type != DT_DIR)
+			else if (entry->d_type != DT_DIR) {
 				continue;
+			}
 #else
 			// Solaris doesn't have d_type
 			bool wasLink;
 			alloc_path_buffer(entry->d_name);
 			strcpy(m_file_part, entry->d_name);
-			if (get_file_info(m_raw_path, wasLink, 0, 0, 0) != dir)
+			if (get_file_info(m_raw_path, wasLink, nullptr, nullptr, nullptr) != dir) {
 				continue;
+			}
 #endif
 		}
 
@@ -397,31 +402,33 @@ bool local_filesys::get_next_file(native_string& name)
 bool local_filesys::get_next_file(native_string& name, bool &is_link, bool &is_dir, int64_t* size, datetime* modification_time, int* mode)
 {
 #ifdef FZ_WINDOWS
-	if (!m_found)
+	if (!has_next_) {
 		return false;
+	}
 	do {
 		if (!m_find_data.cFileName[0]) {
-			m_found = FindNextFile(m_hFind, &m_find_data) != 0;
-			return true;
+			continue;
 		}
-		if (m_dirs_only && !(m_find_data.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY))
+		if (dirs_only_ && !(m_find_data.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY)) {
 			continue;
+		}
 
-		if (m_find_data.cFileName[0] == '.' && (!m_find_data.cFileName[1] || (m_find_data.cFileName[1] == '.' && !m_find_data.cFileName[2])))
+		if (m_find_data.cFileName[0] == '.' && (!m_find_data.cFileName[1] || (m_find_data.cFileName[1] == '.' && !m_find_data.cFileName[2]))) {
 			continue;
+		}
 		name = m_find_data.cFileName;
 
 		is_dir = (m_find_data.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY) != 0;
 
-		is_link = (m_find_data.dwFileAttributes & FILE_ATTRIBUTE_REPARSE_POINT) != 0;
+		is_link = (m_find_data.dwFileAttributes & FILE_ATTRIBUTE_REPARSE_POINT) != 0 && IsReparseTagNameSurrogate(m_find_data.dwReserved0);
 		if (is_link) {
 			// Follow the reparse point
-			HANDLE hFile = is_dir ? INVALID_HANDLE_VALUE : CreateFile((m_find_path + name).c_str(), FILE_READ_ATTRIBUTES | FILE_READ_EA, FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE, 0, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, 0);
+			HANDLE hFile = is_dir ? INVALID_HANDLE_VALUE : CreateFile((m_find_path + name).c_str(), FILE_READ_ATTRIBUTES | FILE_READ_EA, FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE, nullptr, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, nullptr);
 			if (hFile != INVALID_HANDLE_VALUE) {
 				BY_HANDLE_FILE_INFORMATION info{};
 				int ret = GetFileInformationByHandle(hFile, &info);
 				CloseHandle(hFile);
-				if (ret != 0 && !(info.dwFileAttributes & FILE_ATTRIBUTE_REPARSE_POINT)) {
+				if (ret != 0) {
 
 					if (modification_time) {
 						*modification_time = datetime(info.ftLastWriteTime, datetime::milliseconds);
@@ -430,8 +437,9 @@ bool local_filesys::get_next_file(native_string& name, bool &is_link, bool &is_d
 						}
 					}
 
-					if (mode)
+					if (mode) {
 						*mode = (int)info.dwFileAttributes;
+					}
 
 					is_dir = (info.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY) != 0;
 					if (size) {
@@ -443,21 +451,24 @@ bool local_filesys::get_next_file(native_string& name, bool &is_link, bool &is_d
 						}
 					}
 
-					m_found = FindNextFile(m_hFind, &m_find_data) != 0;
+					has_next_ = FindNextFile(m_hFind, &m_find_data) != 0;
 					return true;
 				}
 			}
 
-			if (m_dirs_only && !is_dir) {
+			if (dirs_only_ && !is_dir) {
 				continue;
 			}
 
-			if (size)
+			if (size) {
 				*size = -1;
-			if (mode)
+			}
+			if (mode) {
 				*mode = 0;
-			if (modification_time)
+			}
+			if (modification_time) {
 				*modification_time = datetime();
+			}
 		}
 		else {
 			if (modification_time) {
@@ -467,8 +478,9 @@ bool local_filesys::get_next_file(native_string& name, bool &is_link, bool &is_d
 				}
 			}
 
-			if (mode)
+			if (mode) {
 				*mode = (int)m_find_data.dwFileAttributes;
+			}
 
 			if (size) {
 				if (is_dir) {
@@ -479,30 +491,32 @@ bool local_filesys::get_next_file(native_string& name, bool &is_link, bool &is_d
 				}
 			}
 		}
-		m_found = FindNextFile(m_hFind, &m_find_data) != 0;
+		has_next_ = FindNextFile(m_hFind, &m_find_data) != 0;
 		return true;
-	} while ((m_found = FindNextFile(m_hFind, &m_find_data) != 0));
+	} while ((has_next_ = FindNextFile(m_hFind, &m_find_data) != 0));
 
 	return false;
 #else
-	if (!m_dir)
+	if (!dir_) {
 		return false;
+	}
 
 	struct dirent* entry;
-	while ((entry = readdir(m_dir))) {
+	while ((entry = readdir(dir_))) {
 		if (!entry->d_name[0] ||
 			!strcmp(entry->d_name, ".") ||
 			!strcmp(entry->d_name, ".."))
 			continue;
 
 #if HAVE_STRUCT_DIRENT_D_TYPE
-		if (m_dirs_only) {
+		if (dirs_only_) {
 			if (entry->d_type == DT_LNK) {
 				alloc_path_buffer(entry->d_name);
 				strcpy(m_file_part, entry->d_name);
 				type t = get_file_info(m_raw_path, is_link, size, modification_time, mode);
-				if (t != dir)
+				if (t != dir) {
 					continue;
+				}
 
 				name = entry->d_name;
 				is_dir = true;
@@ -525,15 +539,19 @@ bool local_filesys::get_next_file(native_string& name, bool &is_link, bool &is_d
 			t = file;
 #endif
 			is_link = 0;
-			if (size)
+			if (size) {
 				*size = -1;
-			if (modification_time)
+			}
+			if (modification_time) {
 				*modification_time = datetime();
-			if (mode)
+			}
+			if (mode) {
 				*mode = 0;
+			}
 		}
-		if (m_dirs_only && t != dir)
+		if (dirs_only_ && t != dir) {
 			continue;
+		}
 
 		is_dir = t == dir;
 
@@ -568,16 +586,18 @@ datetime local_filesys::get_modification_time(native_string const& path)
 	datetime mtime;
 
 	bool tmp;
-	if (get_file_info(path, tmp, 0, &mtime, 0) == unknown)
+	if (get_file_info(path, tmp, nullptr, &mtime, nullptr) == unknown) {
 		mtime = datetime();
+	}
 
 	return mtime;
 }
 
 bool local_filesys::set_modification_time(native_string const& path, datetime const& t)
 {
-	if (t.empty())
+	if (t.empty()) {
 		return false;
+	}
 
 #ifdef FZ_WINDOWS
 	FILETIME ft = t.get_filetime();
@@ -585,11 +605,12 @@ bool local_filesys::set_modification_time(native_string const& path, datetime co
 		return false;
 	}
 
-	HANDLE h = CreateFile(path.c_str(), GENERIC_WRITE, FILE_SHARE_WRITE | FILE_SHARE_READ, 0, OPEN_EXISTING, 0, 0);
-	if (h == INVALID_HANDLE_VALUE)
+	HANDLE h = CreateFile(path.c_str(), GENERIC_WRITE, FILE_SHARE_WRITE | FILE_SHARE_READ, nullptr, OPEN_EXISTING, 0, nullptr);
+	if (h == INVALID_HANDLE_VALUE) {
 		return false;
+	}
 
-	bool ret = SetFileTime(h, 0, &ft, &ft) == TRUE;
+	bool ret = SetFileTime(h, nullptr, &ft, &ft) == TRUE;
 	CloseHandle(h);
 	return ret;
 #else
@@ -604,7 +625,7 @@ int64_t local_filesys::get_size(native_string const& path, bool* is_link)
 {
 	int64_t ret = -1;
 	bool tmp{};
-	type t = get_file_info(path, is_link ? *is_link : tmp, &ret, 0, 0);
+	type t = get_file_info(path, is_link ? *is_link : tmp, &ret, nullptr, nullptr);
 	if (t != file) {
 		ret = -1;
 	}
@@ -617,7 +638,7 @@ native_string local_filesys::get_link_target(native_string const& path)
 	native_string target;
 
 #ifdef FZ_WINDOWS
-	HANDLE hFile = CreateFile(path.c_str(), FILE_READ_ATTRIBUTES | FILE_READ_EA, FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE, 0, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, 0);
+	HANDLE hFile = CreateFile(path.c_str(), FILE_READ_ATTRIBUTES | FILE_READ_EA, FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE, nullptr, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, nullptr);
 	if (hFile != INVALID_HANDLE_VALUE) {
 		DWORD const size = 1024;
 		native_string::value_type out[size];
