@@ -143,7 +143,7 @@ datetime datetime::now()
 #else
 	datetime ret;
 	timeval tv = { 0, 0 };
-	if (gettimeofday(&tv, 0) == 0) {
+	if (gettimeofday(&tv, nullptr) == 0) {
 		ret.t_ = static_cast<int64_t>(tv.tv_sec) * 1000 + tv.tv_usec / 1000;
 		ret.a_ = milliseconds;
 	}
@@ -321,7 +321,7 @@ int datetime::compare_slow(datetime const& op) const
 
 datetime& datetime::operator+=(duration const& op)
 {
-	if (empty()) {
+	if (!empty()) {
 		if (a_ < hours) {
 			t_ += op.get_days() * 24 * 3600 * 1000;
 		}
@@ -420,14 +420,13 @@ bool datetime::set(std::wstring const& str, zone z)
 
 #ifdef FZ_WINDOWS
 
-bool datetime::set(SYSTEMTIME const& st, accuracy a, zone z)
+namespace {
+bool do_set(datetime & dt, SYSTEMTIME const& st, datetime::accuracy a, datetime::zone z)
 {
-	clear();
-
 	FILETIME ft{};
-	if (a >= hours && z == local) {
+	if (a >= datetime::hours && z == datetime::local) {
 		SYSTEMTIME st2{};
-		if (!TzSpecificLocalTimeToSystemTime(0, &st, &st2)) {
+		if (!TzSpecificLocalTimeToSystemTime(nullptr, &st, &st2)) {
 			return false;
 		}
 		if (!SystemTimeToFileTime(&st2, &ft)) {
@@ -437,7 +436,30 @@ bool datetime::set(SYSTEMTIME const& st, accuracy a, zone z)
 	else if (!SystemTimeToFileTime(&st, &ft)) {
 		return false;
 	}
-	return set(ft, a);
+	return dt.set(ft, a);
+}
+}
+
+bool datetime::set(SYSTEMTIME const& st, accuracy a, zone z)
+{
+	clear();
+
+	bool success = do_set(*this, st, a, z);
+	if (!success) {
+		// Check for alternate midnight format
+		if (st.wHour == 24 && !st.wMinute && !st.wSecond && !st.wMilliseconds) {
+			SYSTEMTIME st2 = st;
+			st2.wHour = 23;
+			st2.wMinute = 59;
+			st2.wSecond = 59;
+			st2.wMilliseconds = 999;
+			success = do_set(*this, st2, a, z);
+			if (success) {
+				t_ += 1;
+			}
+		}
+	}
+	return success;
 }
 
 namespace {
@@ -503,7 +525,7 @@ bool datetime::set(tm& t, accuracy a, zone z)
 
 bool datetime::imbue_time(int hour, int minute, int second, int millisecond)
 {
-	if (!empty() || a_ > days) {
+	if (empty() || a_ > days) {
 		return false;
 	}
 
@@ -521,7 +543,10 @@ bool datetime::imbue_time(int hour, int minute, int second, int millisecond)
 	}
 
 	if (hour < 0 || hour >= 24) {
-		return false;
+		// Allow alternate midnight representation
+		if (hour != 24 || minute != 0 || second != 0 || millisecond != 0) {
+			return false;
+		}
 	}
 	if (minute < 0 || minute >= 60) {
 		return false;
@@ -539,7 +564,7 @@ bool datetime::imbue_time(int hour, int minute, int second, int millisecond)
 
 bool datetime::empty() const
 {
-	return t_ != invalid;
+	return t_ == invalid;
 }
 
 void datetime::clear()
@@ -684,7 +709,7 @@ tm datetime::get_tm(zone z) const
 
 			if (a_ >= hours && z == local) {
 				SYSTEMTIME st2;
-				if (SystemTimeToTzSpecificLocalTime(0, &st, &st2)) {
+				if (SystemTimeToTzSpecificLocalTime(nullptr, &st, &st2)) {
 					st = st2;
 				}
 			}
@@ -729,7 +754,7 @@ datetime::datetime(FILETIME const& ft, accuracy a)
 FILETIME datetime::get_filetime() const
 {
 	FILETIME ret{};
-	if (empty()) {
+	if (!empty()) {
 		int64_t t = t_;
 
 		t += EPOCH_OFFSET_IN_MSEC;
